==> jc-1.4.0.tar.gz: soot/javaToJimple/ReturnStmtChecker.h <==
// public class soot.javaToJimple.ReturnStmtChecker

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 534db787197439f0 polyglot_visit_NodeVisitor
// @dep_class e63298a4b3a776b2 soot_javaToJimple_ReturnStmtChecker

// header file dependencies
// @dep_header polyglot_visit_NodeVisitor

#include "polyglot/visit/NodeVisitor.h"

#ifndef _JC_soot_javaToJimple_ReturnStmtChecker_H_
#define _JC_soot_javaToJimple_ReturnStmtChecker_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_visit_NodeVisitor$object;

// Typedefs
typedef struct _jc_soot_javaToJimple_ReturnStmtChecker$sub_refs	_jc_soot_javaToJimple_ReturnStmtChecker$sub_refs;
typedef struct _jc_soot_javaToJimple_ReturnStmtChecker$sub_nonrefs	_jc_soot_javaToJimple_ReturnStmtChecker$sub_nonrefs;
typedef struct _jc_soot_javaToJimple_ReturnStmtChecker$refs	_jc_soot_javaToJimple_ReturnStmtChecker$refs;
typedef struct _jc_soot_javaToJimple_ReturnStmtChecker$nonrefs	_jc_soot_javaToJimple_ReturnStmtChecker$nonrefs;
typedef struct _jc_soot_javaToJimple_ReturnStmtChecker$object	_jc_soot_javaToJimple_ReturnStmtChecker$object;

typedef const struct _jc_soot_javaToJimple_ReturnStmtChecker$vmethods	_jc_soot_javaToJimple_ReturnStmtChecker$vmethods;
typedef const struct _jc_soot_javaToJimple_ReturnStmtChecker$vtable	_jc_soot_javaToJimple_ReturnStmtChecker$vtable;
typedef const struct _jc_soot_javaToJimple_ReturnStmtChecker$vtype	_jc_soot_javaToJimple_ReturnStmtChecker$vtype;

// Constructors
extern void _jc_soot_javaToJimple_ReturnStmtChecker$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_javaToJimple_ReturnStmtChecker$object *);

// Virtual methods
extern jboolean _jc_soot_javaToJimple_ReturnStmtChecker$method$hasRet$5dbd85e593475c1b(_jc_env *, struct _jc_soot_javaToJimple_ReturnStmtChecker$object *);
extern struct _jc_object *_jc_soot_javaToJimple_ReturnStmtChecker$method$leave$cf18a0cab654af63(_jc_env *, struct _jc_soot_javaToJimple_ReturnStmtChecker$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_javaToJimple_ReturnStmtChecker$method_info$hasRet$5dbd85e593475c1b;
extern _jc_method _jc_soot_javaToJimple_ReturnStmtChecker$method_info$leave$cf18a0cab654af63;

// Virtual methods structure
struct _jc_soot_javaToJimple_ReturnStmtChecker$vmethods {
	jboolean	(*hasRet$5dbd85e593475c1b)(_jc_env *, struct _jc_soot_javaToJimple_ReturnStmtChecker$object *);
	struct _jc_object	*(*leave$cf18a0cab654af63)(_jc_env *, struct _jc_soot_javaToJimple_ReturnStmtChecker$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *);
};

// Vtable
struct _jc_soot_javaToJimple_ReturnStmtChecker$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_NodeVisitor$vmethods	polyglot_visit_NodeVisitor;
	_jc_soot_javaToJimple_ReturnStmtChecker$vmethods	soot_javaToJimple_ReturnStmtChecker;
};

// Vtype
struct _jc_soot_javaToJimple_ReturnStmtChecker$vtype {
	_jc_type			type;
	_jc_soot_javaToJimple_ReturnStmtChecker$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_javaToJimple_ReturnStmtChecker$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_javaToJimple_ReturnStmtChecker$refs {
    _jc_soot_javaToJimple_ReturnStmtChecker$sub_refs	soot_javaToJimple_ReturnStmtChecker;
    _jc_polyglot_visit_NodeVisitor$sub_refs	polyglot_visit_NodeVisitor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_javaToJimple_ReturnStmtChecker$sub_nonrefs {
	jboolean	hasReturn;
};

// Non-reference instance fields (object)
struct _jc_soot_javaToJimple_ReturnStmtChecker$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_NodeVisitor$sub_nonrefs	polyglot_visit_NodeVisitor;
    _jc_soot_javaToJimple_ReturnStmtChecker$sub_nonrefs	soot_javaToJimple_ReturnStmtChecker;
};

// Object instance structure
struct _jc_soot_javaToJimple_ReturnStmtChecker$object {
	_jc_soot_javaToJimple_ReturnStmtChecker$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_javaToJimple_ReturnStmtChecker$vtype	*vtype;
	_jc_soot_javaToJimple_ReturnStmtChecker$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_javaToJimple_ReturnStmtChecker$vtype _jc_soot_javaToJimple_ReturnStmtChecker$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_javaToJimple_ReturnStmtChecker, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_javaToJimple_ReturnStmtChecker$class_object;

#endif	/* _JC_soot_javaToJimple_ReturnStmtChecker_H_ */

==> jc-1.4.6.tar.gz: soot/javaToJimple/ReturnStmtChecker.h <==
// public class soot.javaToJimple.ReturnStmtChecker

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 534db787197439f0 polyglot_visit_NodeVisitor
// @dep_class e63298a4b3a776b2 soot_javaToJimple_ReturnStmtChecker

// header file dependencies
// @dep_header polyglot_visit_NodeVisitor

#include "polyglot/visit/NodeVisitor.h"

#ifndef _JC_soot_javaToJimple_ReturnStmtChecker_H_
#define _JC_soot_javaToJimple_ReturnStmtChecker_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_visit_NodeVisitor$object;

// Typedefs
typedef struct _jc_soot_javaToJimple_ReturnStmtChecker$sub_refs	_jc_soot_javaToJimple_ReturnStmtChecker$sub_refs;
typedef struct _jc_soot_javaToJimple_ReturnStmtChecker$sub_nonrefs	_jc_soot_javaToJimple_ReturnStmtChecker$sub_nonrefs;
typedef struct _jc_soot_javaToJimple_ReturnStmtChecker$refs	_jc_soot_javaToJimple_ReturnStmtChecker$refs;
typedef struct _jc_soot_javaToJimple_ReturnStmtChecker$nonrefs	_jc_soot_javaToJimple_ReturnStmtChecker$nonrefs;
typedef struct _jc_soot_javaToJimple_ReturnStmtChecker$object	_jc_soot_javaToJimple_ReturnStmtChecker$object;

typedef const struct _jc_soot_javaToJimple_ReturnStmtChecker$vmethods	_jc_soot_javaToJimple_ReturnStmtChecker$vmethods;
typedef const struct _jc_soot_javaToJimple_ReturnStmtChecker$vtable	_jc_soot_javaToJimple_ReturnStmtChecker$vtable;
typedef const struct _jc_soot_javaToJimple_ReturnStmtChecker$vtype	_jc_soot_javaToJimple_ReturnStmtChecker$vtype;

// Constructors
extern void _jc_soot_javaToJimple_ReturnStmtChecker$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_javaToJimple_ReturnStmtChecker$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_javaToJimple_ReturnStmtChecker$method$hasRet$5dbd85e593475c1b(_jc_env *, struct _jc_soot_javaToJimple_ReturnStmtChecker$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_javaToJimple_ReturnStmtChecker$method$leave$cf18a0cab654af63(_jc_env *, struct _jc_soot_javaToJimple_ReturnStmtChecker$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_javaToJimple_ReturnStmtChecker$method_info$hasRet$5dbd85e593475c1b;
extern _jc_method _jc_soot_javaToJimple_ReturnStmtChecker$method_info$leave$cf18a0cab654af63;

// Virtual methods structure
struct _jc_soot_javaToJimple_ReturnStmtChecker$vmethods {
	jboolean	(*hasRet$5dbd85e593475c1b)(_jc_env *, struct _jc_soot_javaToJimple_ReturnStmtChecker$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*leave$cf18a0cab654af63)(_jc_env *, struct _jc_soot_javaToJimple_ReturnStmtChecker$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_javaToJimple_ReturnStmtChecker$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_NodeVisitor$vmethods	polyglot_visit_NodeVisitor;
	_jc_soot_javaToJimple_ReturnStmtChecker$vmethods	soot_javaToJimple_ReturnStmtChecker;
};

// Vtype
struct _jc_soot_javaToJimple_ReturnStmtChecker$vtype {
	_jc_type			type;
	_jc_soot_javaToJimple_ReturnStmtChecker$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_javaToJimple_ReturnStmtChecker$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_javaToJimple_ReturnStmtChecker$refs {
    _jc_soot_javaToJimple_ReturnStmtChecker$sub_refs	soot_javaToJimple_ReturnStmtChecker;
    _jc_polyglot_visit_NodeVisitor$sub_refs	polyglot_visit_NodeVisitor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_javaToJimple_ReturnStmtChecker$sub_nonrefs {
	jboolean	hasReturn;
};

// Non-reference instance fields (object)
struct _jc_soot_javaToJimple_ReturnStmtChecker$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_NodeVisitor$sub_nonrefs	polyglot_visit_NodeVisitor;
    _jc_soot_javaToJimple_ReturnStmtChecker$sub_nonrefs	soot_javaToJimple_ReturnStmtChecker;
};

// Object instance structure
struct _jc_soot_javaToJimple_ReturnStmtChecker$object {
	_jc_soot_javaToJimple_ReturnStmtChecker$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_javaToJimple_ReturnStmtChecker$vtype	*vtype;
	_jc_soot_javaToJimple_ReturnStmtChecker$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_javaToJimple_ReturnStmtChecker$vtype _jc_soot_javaToJimple_ReturnStmtChecker$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_javaToJimple_ReturnStmtChecker, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_javaToJimple_ReturnStmtChecker$class_object;

#endif	/* _JC_soot_javaToJimple_ReturnStmtChecker_H_ */
